import re
from bs4 import BeautifulSoup
import requests


class AppTeka:
    """
    This class provides methods to search for an APK on AppTeka based on package name,
    and to find available versions and their download links for a given APK link.

    Parameters:
        pkg_name (str): The package name of the APK to search for.

    Attributes:
        pkg_name (str): The package name of the APK to search for.
        base_url (str): The base URL of the AppTeka website.
        search_url (str): The URL used to search for APKs on AppTeka.
        headers (dict): The headers used for making HTTP requests.
        session (requests.Session): The session object used for making HTTP requests.

    Methods:
        search_apk(version) -> None | tuple[str, str]:
            Searches for an APK on AppTeka based on the package name and version.
            Returns a tuple containing the APK name and download link if found, otherwise None.
    """

    def __init__(self, pkg_name: str):
        self.pkg_name = pkg_name
        self.base_url = "https://appteka.store"
        self.search_url = self.base_url + "/list/?query="
        self.headers = {
            "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
            "accept-language": "en-US,en;q=0.9,en-IN;q=0.8",
            "cache-control": "no-cache",
            "dnt": "1",
            "connection": "keep-alive",
            "pragma": "no-cache",
            "referer": "https://appteka.store/list/",
            "sec-ch-ua": '"Microsoft Edge";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": '"Windows"',
            "sec-fetch-dest": "document",
            "sec-fetch-mode": "navigate",
            "sec-fetch-site": "same-origin",
            "sec-fetch-user": "?1",
            "upgrade-insecure-requests": "1",
            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36 Edg/131.0.0.0",
        }
        self.session = requests.Session()

    def search_apk(self, version: str = None) -> None | tuple[str, str]:
        """
        Searches for the APK on AppTeka and returns the title and link if found.

        Parameters:
           version (str, optional): The version of the APK to search for.

        Returns:
            None: If no matching APK is found.
            tuple[str, str]: A tuple containing the title and link of the matching APK if found.
        """
        pkg_name = self.pkg_name
        url = self.search_url + pkg_name
        response: requests.Response = self.session.get(url, headers=self.headers)
        soup = BeautifulSoup(response.text, "html.parser")
        search_results = soup.find("div", {"class": "list-group"})
        if search_results:
            apk_items = search_results.find_all(
                "a",
                {"class": "list-group-item list-group-item-action d-flex gap-3 py-3"},
            )
            if apk_items:
                for apk_item in apk_items:
                    apk_link = self.base_url + apk_item["href"]
                    apk_title = apk_item.find(
                        "strong", {"class": "text-gray-dark"}
                    ).text.strip()
                    # Unfortunately, AppTeka does not provide a package name in the search results.
                    # So, we can't compare the package names here.
                    # We can instead do a workaround by doing a request to the apk_link and check the package name there.
                    new_url = apk_link
                    new_response: requests.Response = self.session.get(
                        new_url, headers=self.headers
                    )
                    new_soup = BeautifulSoup(new_response.text, "html.parser")
                    rows = new_soup.find_all("dl", {"class": "row"})
                    for row in rows:
                        dt_tags = row.find_all("dt")
                        dd_tags = row.find_all("dd")
                        for dt, dd in zip(dt_tags, dd_tags):
                            if dt.text.strip() == "Package":
                                package_name = dd.text.strip()
                                if package_name == pkg_name:
                                    # Appteka also stores the list of all the versions on same page
                                    # So, if the version param is given then we can check if the version is available or not
                                    if version:
                                        version_modal = new_soup.find(
                                            "div", {"id": "versionsModal"}
                                        )
                                        if version_modal:
                                            version_links = version_modal.find_all(
                                                "a",
                                                {
                                                    "class": re.compile(
                                                        "^list-group-item list-group-item-action*"
                                                    )
                                                },
                                            )
                                            for link in version_links:
                                                version_text = (
                                                    link.find("p", {"class": "m-1"})
                                                    .text.strip()
                                                    .split("\xa0")[0]
                                                )
                                                if version_text == version:
                                                    apk_link = (
                                                        self.base_url + link["href"]
                                                    )
                                                    return apk_title, apk_link
                                            return apk_title, None
                                    else:
                                        return apk_title, apk_link

        return None



import re
from bs4 import BeautifulSoup
import requests


class APKPure:
    """
    This class provides methods to search for an APK on APKPure based on package name,
    and to find available versions and their download links for a given APK link.

    Parameters:
        pkg_name (str): The package name of the APK to search for.

    Attributes:
        pkg_name (str): The package name of the APK to search for.
        base_url (str): The base URL of the APKPure website.
        search_url (str): The URL used to search for APKs on APKPure.
        headers (dict): The headers used for making HTTP requests.
        session (requests.Session): The session object used for making HTTP requests.

    Methods:
        search_apk() -> None | tuple[str, str]:
            Searches for the APK on APKPure and returns the title and link if found.

        find_versions(apk_link: str) -> list[tuple[str, str]]:
            Finds and returns a list of versions and their download links for the given APK link.
    """

    def __init__(self, pkg_name: str):
        self.pkg_name = pkg_name
        self.base_url = "https://apkpure.net"
        self.cdn_url = "https://d.cdnpure.com/b/APK/"
        self.cdn_version = "?version="
        self.search_url = self.base_url + "/search?q="
        self.headers = {
            "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
            "accept-language": "en-US,en;q=0.9,en-IN;q=0.8",
            "cache-control": "no-cache",
            "dnt": "1",
            "pragma": "no-cache",
            "priority": "u=0, i",
            "referer": "https://apkpure.net/",
            "sec-ch-ua": '"Microsoft Edge";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": '"Windows"',
            "sec-fetch-dest": "document",
            "sec-fetch-mode": "navigate",
            "sec-fetch-site": "same-origin",
            "sec-fetch-user": "?1",
            "upgrade-insecure-requests": "1",
            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36 Edg/131.0.0.0",
        }
        self.session = requests.Session()

    def search_apk(self) -> None | tuple[str, str]:
        """
        Searches for the APK on APKPure and returns the title and link if found.

        Returns:
            None: If no matching APK is found.
            tuple[str, str]: A tuple containing the title and link of the matching APK if found.
        """
        pkg_name = self.pkg_name
        url = self.search_url + pkg_name
        response: requests.Response = self.session.get(url, headers=self.headers)
        soup = BeautifulSoup(response.text, "html.parser")
        search_results = soup.find("div", {"class": "apk-list"})
        if search_results:
            apk_items = search_results.find_all("a", {"class": "apk-item"})
            if apk_items:
                for apk_item in apk_items:
                    apk_link = self.base_url + apk_item["href"]
                    apk_title = apk_item["title"]
                    apk_package_name = apk_item["data-dt-pkg"]
                    if apk_package_name == pkg_name:
                        return apk_title, apk_link
        # If site search resulted 0 results, try cdn link
        # https://github.com/AbhiTheModder/apksearch/issues/2
        url = self.cdn_url + pkg_name + self.cdn_version + "latest"
        response: requests.Response = self.session.get(
            url, headers=self.headers, allow_redirects=False
        )
        try:
            location = response.headers.get("Location")
        except AttributeError:
            return None
        if location:
            if location == "https://apkpure.com":
                return None
            response: requests.Response = self.session.head(
                location, allow_redirects=False
            )
            try:
                content = response.headers.get("Content-Disposition")
            except AttributeError:
                return None
            if content:
                apk_title = content.split("filename=")[1].strip('"').split("_")[0]
                return apk_title, location
        return None

    def find_versions(self, apk_link: str) -> list[tuple[str, str]]:
        """
        Finds and returns a list of versions and their download links for the given APK link.

        Parameters:
            apk_link (str): The link to the APK on the APKPure website.

        Returns:
            list[tuple[str, str]]: A list of tuples, where each tuple contains the version number
            and its corresponding download link. If no versions are found, an empty list is returned.
        """
        versions_info = []
        if apk_link.startswith(self.base_url):
            url = apk_link + "/versions"
            response: requests.Response = self.session.get(url, headers=self.headers)
            soup = BeautifulSoup(response.text, "html.parser")
            versions_list = soup.find("ul", {"class": "version-list"})

            if versions_list:
                versions = versions_list.find_all(
                    "li", {"class": re.compile("^version dt-version-item.*")}
                )
                for ver in versions:
                    version_icon = ver.find("a", {"class": "dt-version-icon"})
                    version_info = ver.find("div", {"class": "version-info"})
                    if version_icon and version_info:
                        version_number = version_info.find(
                            "span", {"class": "name one-line"}
                        ).text
                        download_url = self.base_url + version_icon["href"]
                        versions_info.append((version_number, download_url))
        return versions_info



from bs4 import BeautifulSoup
import requests


class APKFab:
    """
    This class provides methods to search for an APK on APKFab based on package name,
    and to find available versions and their download links for a given APK link.

    Parameters:
        pkg_name (str): The package name of the APK to search for.

    Attributes:
        pkg_name (str): The package name of the APK to search for.
        base_url (str): The base URL of the APKFab website.
        search_url (str): The URL used to search for APKs on APKFab.
        headers (dict): The headers used for making HTTP requests.
        session (requests.Session): The session object used for making HTTP requests.

    Methods:
        search_apk() -> None | tuple[str, str]:
            Searches for the APK on APKFab and returns the title and link if found.

        find_versions(apk_link: str) -> list[tuple[str, str]]:
            Finds and returns a list of versions and their download links for the given APK link.
    """

    def __init__(self, pkg_name: str):
        self.pkg_name = pkg_name
        self.base_url = "https://apkfab.com"
        self.search_url = self.base_url + "/search?q="
        self.headers = {
            "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
            "accept-language": "en-US,en;q=0.9,en-IN;q=0.8",
            "cache-control": "no-cache",
            "dnt": "1",
            "pragma": "no-cache",
            "priority": "u=0, i",
            "referer": "https://apkfab.com/search",
            "sec-ch-ua": '"Microsoft Edge";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": '"Windows"',
            "sec-fetch-dest": "document",
            "sec-fetch-mode": "navigate",
            "sec-fetch-site": "same-origin",
            "sec-fetch-user": "?1",
            "upgrade-insecure-requests": "1",
            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36 Edg/131.0.0.0",
        }
        self.session = requests.Session()

    def search_apk(self) -> None | tuple[str, str]:
        """
        Searches for the APK on APKFab and returns the title and link if found.

        Returns:
            None: If no matching APK is found.
            tuple[str, str]: A tuple containing the title and link of the matching APK if found.
        """
        pkg_name = self.pkg_name
        url = self.search_url + pkg_name
        response: requests.Response = self.session.get(url, headers=self.headers)
        soup = BeautifulSoup(response.text, "html.parser")
        search_result = soup.find("div", {"class": "search-white"})
        if search_result:
            container = search_result.find("div", {"class": "container"})
            if container:
                lists = container.find("div", {"class": "list-template lists"})
                if lists:
                    items = lists.find_all("div", {"class": "list"})
                    if items:
                        item = items[0]
                        apk_title = item.find("div", {"class": "title"}).text
                        apk_link = item.find("a")["href"]
                        package_name = apk_link.split("/")[-1]
                        if package_name == pkg_name:
                            return apk_title, apk_link
        return None

    def find_versions(self, apk_link: str) -> list[tuple[str, str]]:
        """
        Finds and returns a list of versions and their download links for the given APK link.

        Parameters:
            apk_link (str): The link to the APK on the APKFab website.

        Returns:
            list[tuple[str, str]]: A list of tuples, where each tuple contains the version number
            and its corresponding download link. If no versions are found, an empty list is returned.
        """
        versions_info = []
        if apk_link.startswith(self.base_url):
            url = apk_link + "/versions"
            response: requests.Response = self.session.get(url, headers=self.headers)
            soup = BeautifulSoup(response.text, "html.parser")
            versions_list = soup.find("div", {"class": "version_history"})

            if versions_list:
                versions = versions_list.find_all("div", {"class": "list"})
                if versions:
                    for version in versions:
                        package_info = version.find(
                            "div", {"class": "package_info open_info"}
                        )
                        if package_info:
                            title = package_info.find("div", {"class": "title"})
                            apk_version = title.find(
                                "span", {"class": "version"}
                            ).text.strip()
                            dl = version.find(
                                "div", {"class": "v_h_button button_down"}
                            )
                            if dl:
                                download_link = dl.find("a")["href"]
                                versions_info.append((apk_version, download_link))
                            else:
                                # Some versions have multiple variants
                                versions_info.append((apk_version, url))

        return versions_info



import argparse

from collections.abc import Callable
from apksearch import APKPure, APKMirror, AppTeka, APKCombo, APKFab, APKAD
from requests.exceptions import ConnectionError, ConnectTimeout

# Color codes
BOLD = "\033[1m"
RED = "\033[91m"
GREEN = "\033[92m"
YELLOW = "\033[93m"
NC = "\033[0m"


def search(
    func: Callable[[str, str], object],
    pkg_name: str,
    version: str | None,
    log_err: bool = False,
) -> None:
    try:
        func(pkg_name, version)
    except Exception as exc:
        if log_err:
            print(f"Error in {func.__name__}: {exc}")
        else:
            pass


def search_apkpure(pkg_name: str, version: str | None) -> None:
    apkpure = APKPure(pkg_name)
    try:
        result_apkpure: tuple[str, str] | None = apkpure.search_apk()
    except (ConnectionError, ConnectTimeout):
        result_apkpure = None
        print(f"{RED}Failed to resolve 'apkpure.net'!{NC}")
    if result_apkpure:
        title, apk_link = result_apkpure
        print(f"{BOLD}APKPure:{NC} Found {GREEN}{title}{NC}") if title else None
        print(f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}") if not version else None
        if version:
            versions: list[tuple[str, str]] = apkpure.find_versions(apk_link)
            if versions:
                for version_tuple in versions:
                    if version_tuple[0] == version:
                        print(
                            f"      ╰─> {BOLD}Version: {GREEN}{version}{NC} - {YELLOW}{version_tuple[1]}{NC}"
                        )
                        break
                else:
                    print(f"{BOLD}APKPure:{NC} Version {RED}{version}{NC} not found!")
    else:
        print(f"{BOLD}APKPure:{NC} No Results!")


def search_apkfab(pkg_name: str, version: str | None) -> None:
    apkfab = APKFab(pkg_name)
    try:
        result_apkfab: tuple[str, str] | None = apkfab.search_apk()
    except (ConnectionError, ConnectTimeout):
        result_apkfab = None
        print(f"{RED}Failed to resolve 'apkfab.com'!{NC}")
    if result_apkfab:
        title, apk_link = result_apkfab
        print(f"{BOLD}APKFab:{NC} Found {GREEN}{title}{NC}") if title else None
        print(f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}") if not version else None
        if version:
            versions: list[tuple[str, str]] = apkfab.find_versions(apk_link)
            if versions:
                for version_tuple in versions:
                    if version_tuple[0] == version:
                        print(
                            f"      ╰─> {BOLD}Version: {GREEN}{version}{NC} - {YELLOW}{version_tuple[1]}{NC}"
                        )
                        break
                else:
                    print(f"{BOLD}APKFab:{NC} Version {RED}{version}{NC} not found!")
    else:
        print(f"{BOLD}APKFab:{NC} No Results!")


def search_apkad(pkg_name: str, version: str | None) -> None:
    apkad = APKAD(pkg_name)
    try:
        result_apkad: tuple[str, str] | None = apkad.search_apk()
    except (ConnectionError, ConnectTimeout):
        result_apkad = None
        print(f"{RED}Failed to resolve 'api.apk.ad'!{NC}")
    if result_apkad:
        title, apk_link = result_apkad
        print(f"{BOLD}APKAD:{NC} Found {GREEN}{title}{NC}") if title else None
        print(
            f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}"
        ) if not version else print("      ╰─> Doesn't support version search!")
    else:
        print(f"{BOLD}APKAD:{NC} No Results!")


def search_apkcombo(pkg_name: str, version: str | None) -> None:
    apkcombo = APKCombo(pkg_name)
    try:
        result_apkcombo: tuple[str, str] | None = apkcombo.search_apk()
    except (ConnectionError, ConnectTimeout):
        result_apkcombo = None
        print(f"{RED}Failed to resolve 'apkcombo.app'!{NC}")
    if result_apkcombo:
        title, apk_link = result_apkcombo
        print(f"{BOLD}APKCombo:{NC} Found {GREEN}{title}{NC}") if title else None
        print(f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}") if not version else None
        versions: list[tuple[str, str]] = apkcombo.find_versions(apk_link)
        if version:
            for version_tuple in versions:
                if version_tuple[0] == version:
                    print(
                        f"      ╰─> {BOLD}Version: {GREEN}{version}{NC} - {YELLOW}{version_tuple[1]}{NC}"
                    )
                    break
            else:
                print(f"{BOLD}APKCombo:{NC} Version {RED}{version}{NC} not found!")
    else:
        print(f"{BOLD}APKCombo:{NC} No Results!")


def search_apkmirror(pkg_name: str, version: str | None) -> None:
    apkmirror = APKMirror(pkg_name)
    try:
        result_apkmirror: tuple[str, str] | None = apkmirror.search_apk()
    except (ConnectionError, ConnectTimeout):
        result_apkmirror = None
        print(f"{RED}Failed to resolve 'apkmirror.com'!{NC}")
    if result_apkmirror:
        title, apk_link = result_apkmirror
        print(f"{BOLD}APKMirror:{NC} Found {GREEN}{title}{NC}") if title else None
        print(f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}") if not version else None
        if version:
            download_link = apkmirror.find_version(apk_link, version)
            if download_link:
                print(
                    f"      ╰─> {BOLD}Version: {GREEN}{version}{NC} - {YELLOW}{download_link}{NC}"
                )
            else:
                print(f"{BOLD}APKMirror:{NC} Version {RED}{version}{NC} not found!")
    else:
        print(f"{BOLD}APKMirror:{NC} No Results!")


def search_appteka(pkg_name: str, version: str | None) -> None:
    appteka = AppTeka(pkg_name)
    try:
        result_appteka: tuple[str, str] | None = appteka.search_apk(version)
    except (ConnectionError, ConnectTimeout):
        result_appteka = None
        print(f"{RED}Failed to resolve 'appteka.store'!{NC}")
    if result_appteka:
        title, apk_link = result_appteka
        print(f"{BOLD}AppTeka:{NC} Found {GREEN}{title}{NC}") if title else None
        if version:
            if apk_link:
                print(
                    f"      ╰─> {BOLD}Version: {GREEN}{version}{NC} - {YELLOW}{apk_link}{NC}"
                )
            else:
                print(f"{BOLD}AppTeka:{NC} Version {RED}{version}{NC} not found!")
        else:
            print(f"      ╰─> {BOLD}Link: {YELLOW}{apk_link}{NC}")
    else:
        print(f"{BOLD}AppTeka:{NC} No Results!")


def main():
    parser = argparse.ArgumentParser(
        prog="APKSearch", description="Search for APKs on various websites"
    )
    parser.add_argument("pkg_name", help="The package name of the APK")
    parser.add_argument("--version", help="The version of the APK", required=False)
    parser.add_argument(
        "--log_err", help="Enable error logs", action="store_true", required=False
    )
    args = parser.parse_args()

    pkg_name = args.pkg_name
    version = args.version
    log_err = args.log_err
    print(f"{BOLD}Searching for {YELLOW}{pkg_name}{NC}...")
    # Initiate search on apkpure
    search(search_apkpure, pkg_name, version, log_err)
    # Initiate search on apkmirror
    search(search_apkmirror, pkg_name, version, log_err)
    # Initiate search on appteka
    search(search_appteka, pkg_name, version, log_err)
    # Initiate search on apkcombo
    search(search_apkcombo, pkg_name, version, log_err)
    # Initiate search on apkfab
    search(search_apkfab, pkg_name, version, log_err)
    # Initiate search on apkad
    search(search_apkad, pkg_name, version, log_err)


if __name__ == "__main__":
    main()



import json
from bs4 import BeautifulSoup
import requests


class APKAD:
    """
    This class provides methods to search for an APK on APKAD based on package name,
    and to find available versions and their download links for a given APK link.

    Parameters:
        pkg_name (str): The package name of the APK to search for.

    Attributes:
        pkg_name (str): The package name of the APK to search for.
        base_url (str): The base URL of the APKAD website.
        search_url (str): The URL used to search for APKs on APKAD.
        headers (dict): The headers used for making HTTP requests.
        session (requests.Session): The session object used for making HTTP requests.

    Methods:
        search_apk() -> None | tuple[str, str]:
            Searches for the APK on APKAD and returns the title and link if found.
    """

    def __init__(self, pkg_name: str):
        self.pkg_name = pkg_name
        self.base_url = "https://downloader.apk.ad"
        self.api_url = "https://api.apk.ad"
        self.search_url = (
            self.api_url
            + f"/get?hl=en&package={self.pkg_name}&device=phone&arch=arm64-v8a&vc=&device_id="
        )
        self.headers = {
            "accept": "text/event-stream",
            "accept-language": "en-US,en;q=0.9,en-IN;q=0.8",
            "cache-control": "no-cache",
            "dnt": "1",
            "origin": "https://downloader.apk.ad",
            "pragma": "no-cache",
            "priority": "u=1, i",
            "referer": "https://downloader.apk.ad/",
            "sec-ch-ua": '"Microsoft Edge";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": '"Windows"',
            "sec-fetch-dest": "empty",
            "sec-fetch-mode": "cors",
            "sec-fetch-site": "same-site",
            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36 Edg/131.0.0.0",
        }
        self.session = requests.Session()

    def search_apk(self) -> None | tuple[str, str]:
        """
        Searches for the APK on APKAD and returns the title and link if found.

        Returns:
            None: If no matching APK is found.
            tuple[str, str]: A tuple containing the title and link of the matching APK if found.
        """
        url = self.search_url
        response = self.session.get(url, headers=self.headers, stream=True)
        stream_response = ""
        for line in response.iter_lines():
            if line:
                line_response = line.decode("utf-8")
                if '"progress":100' in line_response:
                    line_response = line_response[6:]
                    stream_response += line_response
                    break
        if stream_response:
            data = json.loads(stream_response)
            html_body = data["html"]
            soup = BeautifulSoup(html_body, "html.parser")
            if not soup:
                return None
            title = soup.find("li", {"class": "_title"})
            if title:
                title = title.text.strip()
                button = soup.find(
                    "button", {"onclick": True, "id": "downloadButtonapk"}
                )["onclick"]
                if button:
                    zip_args = [
                        arg.strip("'")
                        for arg in button.split("zip(")[1].split(")")[0].split(",")
                    ]
                    h = zip_args[0]  # hash
                    p = zip_args[-1]  # type
                    token = zip_args[1]  # token
                    ip = zip_args[2]  # ip
                    google_id = zip_args[3]  # package_name
                    t = zip_args[4]  # time
                    apk_url = f"https://zip.apk.ad/compress?h={h}&p={p}&token={token}&ip={ip}&google_id={google_id}&t={t}"
                    apk_url_response = self.session.get(
                        url=apk_url, headers=self.headers, stream=True
                    )
                    for line in apk_url_response.iter_lines():
                        if line:
                            line_response = line.decode("utf-8")
                            if "File is ready for download." in line_response:
                                line_response = json.loads(line_response)
                                line_html = line_response["html"]
                                line_soup = BeautifulSoup(line_html, "html.parser")
                                download_link = line_soup.find("a")["href"]
                                if download_link.endswith("\n"):
                                    download_link = download_link[:-1]
                                return title, download_link
        return None



from .sites.apkpure import APKPure
from .sites.apkmirror import APKMirror
from .sites.appteka import AppTeka
from .sites.apkcombo import APKCombo
from .sites.apkfab import APKFab
from .sites.apkad import APKAD

__all__ = ["APKPure", "APKMirror", "AppTeka", "APKCombo", "APKFab", "APKAD"]
